# pytdt
![v0.5.2](https://d25lcipzij17d.cloudfront.net/badge.svg?id=gh&type=6&v=0.5.2&x2=0)

A tool for interfacing with and reading TDT blocks in python

## Installation

`pip install pytdt`

## Usage

```
>>> import pytdt

>>> block = pytdt.Block('path/to/block')
>>> block.read_streams()
```
